@@ -7,9 +7,9 @@ from .tag2npy import Tag2Numpy
 
 class Tag2Dicom:
 
-    def __init__(self, tag_file_path, dcm_file_path):
+    def __init__(self, tag_file_path, dcm_file_path_or_obj):
         self.tag_file_path = tag_file_path
-        self.dcm_file_path = dcm_file_path
+        self.dcm_file_path_or_obj = dcm_file_path_or_obj
         self.output_dir = '.'
         self.tag_dcm_file_name = None
         self.tag_dcm_file_path = None
@@ -18,7 +18,10 @@ class Tag2Dicom:
         self.output_dir = output_dir
 
     def execute(self):
-        p = pydicom.dcmread(self.dcm_file_path)
+        if isinstance(self.dcm_file_path_or_obj, str):
+            p = pydicom.dcmread(self.dcm_file_path)
+        else:
+            p = self.dcm_file_path_or_obj
         t2n = Tag2Numpy(self.tag_file_path, (p.Rows, p.Columns))
         pixels_tag = t2n.execute()
         p_new = create_fake_dicom(pixels_tag, p)
